@@ -29,7 +29,13 @@ class Project(
     metaclass=jsii.JSIIMeta,
     jsii_type="@alicloud/ros-cdk-datahub.Project",
 ):
-    '''A ROS resource type:  ``ALIYUN::DATAHUB::Project``.'''
+    '''This class encapsulates and extends the ROS resource type ``ALIYUN::DATAHUB::Project``, which is used to create a DataHub project.
+
+    :Note:
+
+    This class may have some new functions to facilitate development, so it is recommended to use this class instead of ``RosProject``for a more convenient development experience.
+    See https://www.alibabacloud.com/help/ros/developer-reference/aliyun-datahub-project
+    '''
 
     def __init__(
         self,
@@ -38,11 +44,7 @@ class Project(
         props: typing.Union["ProjectProps", typing.Dict[builtins.str, typing.Any]],
         enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
     ) -> None:
-        '''Create a new ``ALIYUN::DATAHUB::Project``.
-
-        Param scope - scope in which this resource is defined
-        Param id    - scoped id of the resource
-        Param props - resource properties
+        '''Param scope - scope in which this resource is defined Param id    - scoped id of the resource Param props - resource properties.
 
         :param scope: -
         :param id: -
@@ -63,6 +65,54 @@ class Project(
         '''Attribute ProjectName: Project name.'''
         return typing.cast(_ros_cdk_core_7adfd82f.IResolvable, jsii.get(self, "attrProjectName"))
 
+    @builtins.property
+    @jsii.member(jsii_name="enableResourcePropertyConstraint")
+    def _enable_resource_property_constraint(self) -> builtins.bool:
+        return typing.cast(builtins.bool, jsii.get(self, "enableResourcePropertyConstraint"))
+
+    @_enable_resource_property_constraint.setter
+    def _enable_resource_property_constraint(self, value: builtins.bool) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__5e854eaff9bd820b0f5c6acb030b746848a40f4d64e759b1ca691f8ac4c2fee9)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
+        jsii.set(self, "enableResourcePropertyConstraint", value)
+
+    @builtins.property
+    @jsii.member(jsii_name="id")
+    def _id(self) -> builtins.str:
+        return typing.cast(builtins.str, jsii.get(self, "id"))
+
+    @_id.setter
+    def _id(self, value: builtins.str) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__2772112ec874e65e2f4e7f11773a012917f0082dca9a46ed8bd592d0884c0893)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
+        jsii.set(self, "id", value)
+
+    @builtins.property
+    @jsii.member(jsii_name="props")
+    def _props(self) -> "ProjectProps":
+        return typing.cast("ProjectProps", jsii.get(self, "props"))
+
+    @_props.setter
+    def _props(self, value: "ProjectProps") -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__4c2afd9238723ca5af0ac0a9607b69d1adef03919b52b19cc1e2e3c4767756cc)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
+        jsii.set(self, "props", value)
+
+    @builtins.property
+    @jsii.member(jsii_name="scope")
+    def _scope(self) -> _ros_cdk_core_7adfd82f.Construct:
+        return typing.cast(_ros_cdk_core_7adfd82f.Construct, jsii.get(self, "scope"))
+
+    @_scope.setter
+    def _scope(self, value: _ros_cdk_core_7adfd82f.Construct) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__06c72d88695c0fef1b2a30a9c30ad64fd0bb0e96ed9790d097b5138482c6ffcf)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
+        jsii.set(self, "scope", value)
+
 
 @jsii.data_type(
     jsii_type="@alicloud/ros-cdk-datahub.ProjectProps",
@@ -76,7 +126,9 @@ class ProjectProps:
         comment: typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable],
         project_name: typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable],
     ) -> None:
-        '''Properties for defining a ``ALIYUN::DATAHUB::Project``.
+        '''Properties for defining a ``Project``.
+
+        See https://www.alibabacloud.com/help/ros/developer-reference/aliyun-datahub-project
 
         :param comment: Property comment: The comment of project.
         :param project_name: Property projectName: The name of the project. Length [3, 32]. Beginning with characters, only characters, numbers and _ are allowed.
@@ -126,7 +178,13 @@ class RosProject(
     metaclass=jsii.JSIIMeta,
     jsii_type="@alicloud/ros-cdk-datahub.RosProject",
 ):
-    '''A ROS template type:  ``ALIYUN::DATAHUB::Project``.'''
+    '''This class is a base encapsulation around the ROS resource type ``ALIYUN::DATAHUB::Project``, which is used to create a DataHub project.
+
+    :Note:
+
+    This class does not contain additional functions, so it is recommended to use the ``Project`` class instead of this class for a more convenient development experience.
+    See https://www.alibabacloud.com/help/ros/developer-reference/aliyun-datahub-project
+    '''
 
     def __init__(
         self,
@@ -135,8 +193,7 @@ class RosProject(
         props: typing.Union["RosProjectProps", typing.Dict[builtins.str, typing.Any]],
         enable_resource_property_constraint: builtins.bool,
     ) -> None:
-        '''Create a new ``ALIYUN::DATAHUB::Project``.
-
+        '''
         :param scope: - scope in which this resource is defined.
         :param id: - scoped id of the resource.
         :param props: - resource properties.
@@ -245,7 +302,9 @@ class RosProjectProps:
         comment: typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable],
         project_name: typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable],
     ) -> None:
-        '''Properties for defining a ``ALIYUN::DATAHUB::Project``.
+        '''Properties for defining a ``RosProject``.
+
+        See https://www.alibabacloud.com/help/ros/developer-reference/aliyun-datahub-project
 
         :param comment: 
         :param project_name: 
@@ -296,7 +355,13 @@ class RosTopic(
     metaclass=jsii.JSIIMeta,
     jsii_type="@alicloud/ros-cdk-datahub.RosTopic",
 ):
-    '''A ROS template type:  ``ALIYUN::DATAHUB::Topic``.'''
+    '''This class is a base encapsulation around the ROS resource type ``ALIYUN::DATAHUB::Topic``, which is used to create a topic.
+
+    :Note:
+
+    This class does not contain additional functions, so it is recommended to use the ``Topic`` class instead of this class for a more convenient development experience.
+    See https://www.alibabacloud.com/help/ros/developer-reference/aliyun-datahub-topic
+    '''
 
     def __init__(
         self,
@@ -305,8 +370,7 @@ class RosTopic(
         props: typing.Union["RosTopicProps", typing.Dict[builtins.str, typing.Any]],
         enable_resource_property_constraint: builtins.bool,
     ) -> None:
-        '''Create a new ``ALIYUN::DATAHUB::Topic``.
-
+        '''
         :param scope: - scope in which this resource is defined.
         :param id: - scoped id of the resource.
         :param props: - resource properties.
@@ -536,7 +600,9 @@ class RosTopicProps:
         record_schema: typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]] = None,
         shard_count: typing.Optional[typing.Union[jsii.Number, _ros_cdk_core_7adfd82f.IResolvable]] = None,
     ) -> None:
-        '''Properties for defining a ``ALIYUN::DATAHUB::Topic``.
+        '''Properties for defining a ``RosTopic``.
+
+        See https://www.alibabacloud.com/help/ros/developer-reference/aliyun-datahub-topic
 
         :param comment: 
         :param project_name: 
@@ -657,7 +723,13 @@ class Topic(
     metaclass=jsii.JSIIMeta,
     jsii_type="@alicloud/ros-cdk-datahub.Topic",
 ):
-    '''A ROS resource type:  ``ALIYUN::DATAHUB::Topic``.'''
+    '''This class encapsulates and extends the ROS resource type ``ALIYUN::DATAHUB::Topic``, which is used to create a topic.
+
+    :Note:
+
+    This class may have some new functions to facilitate development, so it is recommended to use this class instead of ``RosTopic``for a more convenient development experience.
+    See https://www.alibabacloud.com/help/ros/developer-reference/aliyun-datahub-topic
+    '''
 
     def __init__(
         self,
@@ -666,11 +738,7 @@ class Topic(
         props: typing.Union["TopicProps", typing.Dict[builtins.str, typing.Any]],
         enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
     ) -> None:
-        '''Create a new ``ALIYUN::DATAHUB::Topic``.
-
-        Param scope - scope in which this resource is defined
-        Param id    - scoped id of the resource
-        Param props - resource properties
+        '''Param scope - scope in which this resource is defined Param id    - scoped id of the resource Param props - resource properties.
 
         :param scope: -
         :param id: -
@@ -697,6 +765,54 @@ class Topic(
         '''Attribute TopicName: Topic name.'''
         return typing.cast(_ros_cdk_core_7adfd82f.IResolvable, jsii.get(self, "attrTopicName"))
 
+    @builtins.property
+    @jsii.member(jsii_name="enableResourcePropertyConstraint")
+    def _enable_resource_property_constraint(self) -> builtins.bool:
+        return typing.cast(builtins.bool, jsii.get(self, "enableResourcePropertyConstraint"))
+
+    @_enable_resource_property_constraint.setter
+    def _enable_resource_property_constraint(self, value: builtins.bool) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__7f5873d0a921af168da7e2c604725d81a50bd259914ec439092b72f671752291)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
+        jsii.set(self, "enableResourcePropertyConstraint", value)
+
+    @builtins.property
+    @jsii.member(jsii_name="id")
+    def _id(self) -> builtins.str:
+        return typing.cast(builtins.str, jsii.get(self, "id"))
+
+    @_id.setter
+    def _id(self, value: builtins.str) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__0948f13a81e4189de3845c7295ce493ab141c70c1f0629af96ae9adc8208103e)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
+        jsii.set(self, "id", value)
+
+    @builtins.property
+    @jsii.member(jsii_name="props")
+    def _props(self) -> "TopicProps":
+        return typing.cast("TopicProps", jsii.get(self, "props"))
+
+    @_props.setter
+    def _props(self, value: "TopicProps") -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__36edddfe92eb1df6baee8c72d3f3376699015f0e4f89a4fd233af5a05e2bf5c3)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
+        jsii.set(self, "props", value)
+
+    @builtins.property
+    @jsii.member(jsii_name="scope")
+    def _scope(self) -> _ros_cdk_core_7adfd82f.Construct:
+        return typing.cast(_ros_cdk_core_7adfd82f.Construct, jsii.get(self, "scope"))
+
+    @_scope.setter
+    def _scope(self, value: _ros_cdk_core_7adfd82f.Construct) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__61199bdbbd86b02e5906bed73519a5cac1c1a0fbda77b8c6879fcd70d66eef0f)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
+        jsii.set(self, "scope", value)
+
 
 @jsii.data_type(
     jsii_type="@alicloud/ros-cdk-datahub.TopicProps",
@@ -723,7 +839,9 @@ class TopicProps:
         record_schema: typing.Optional[typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable]] = None,
         shard_count: typing.Optional[typing.Union[jsii.Number, _ros_cdk_core_7adfd82f.IResolvable]] = None,
     ) -> None:
-        '''Properties for defining a ``ALIYUN::DATAHUB::Topic``.
+        '''Properties for defining a ``Topic``.
+
+        See https://www.alibabacloud.com/help/ros/developer-reference/aliyun-datahub-topic
 
         :param comment: Property comment: The comment of topic.
         :param project_name: Property projectName: The name of the project. Length [3, 32]. Beginning with characters, only characters, numbers and _ are allowed.
@@ -856,6 +974,30 @@ def _typecheckingstub__50dfc056b9398a9ab9b34003ab17cd155bbec18da3d12878eb2e9aea7
     """Type checking stubs"""
     pass
 
+def _typecheckingstub__5e854eaff9bd820b0f5c6acb030b746848a40f4d64e759b1ca691f8ac4c2fee9(
+    value: builtins.bool,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__2772112ec874e65e2f4e7f11773a012917f0082dca9a46ed8bd592d0884c0893(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__4c2afd9238723ca5af0ac0a9607b69d1adef03919b52b19cc1e2e3c4767756cc(
+    value: ProjectProps,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__06c72d88695c0fef1b2a30a9c30ad64fd0bb0e96ed9790d097b5138482c6ffcf(
+    value: _ros_cdk_core_7adfd82f.Construct,
+) -> None:
+    """Type checking stubs"""
+    pass
+
 def _typecheckingstub__9caf7bd29056a8268cf50ee1d063260066d8323d82fc4af1d3b315db6f267492(
     *,
     comment: typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable],
@@ -990,6 +1132,30 @@ def _typecheckingstub__6f65435665b7039f0e596bf268460f6a9aa1ccc244db93ee8254e7400
     """Type checking stubs"""
     pass
 
+def _typecheckingstub__7f5873d0a921af168da7e2c604725d81a50bd259914ec439092b72f671752291(
+    value: builtins.bool,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__0948f13a81e4189de3845c7295ce493ab141c70c1f0629af96ae9adc8208103e(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__36edddfe92eb1df6baee8c72d3f3376699015f0e4f89a4fd233af5a05e2bf5c3(
+    value: TopicProps,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__61199bdbbd86b02e5906bed73519a5cac1c1a0fbda77b8c6879fcd70d66eef0f(
+    value: _ros_cdk_core_7adfd82f.Construct,
+) -> None:
+    """Type checking stubs"""
+    pass
+
 def _typecheckingstub__2d2a1de7a80dae497915bfcd85a2674bf386ba9d994d93bcd20cfa68aa5c537c(
     *,
     comment: typing.Union[builtins.str, _ros_cdk_core_7adfd82f.IResolvable],
